@@ -1,19 +1,19 @@
+CLINICAL_WITHDRAWAL = "clinical_withdrawal"
 CLINICIAN = "clinician"
 DEATH_REPORT_ACTION = "submit_death_report"
 DEVIATION = "protocol_deviation"
 INVESTIGATOR = "investigator"
+INVESTIGATOR_DECISION = "investigator_decision"
 LATE_EXCLUSION = "late_exclusion"
 LOSS_TO_FOLLOWUP_ACTION = "submit_loss_to_followup"
 OFFSCHEDULE_ACTION = "offschedule_action"
 OFFSCHEDULE_POSTNATAL_ACTION = "offschedule_postnatal_action"
 OFFSCHEDULE_PREGNANCY_ACTION = "offschedule_pregnancy_action"
 OTHER_RX_DISCONTINUATION = "other_treatment_discontinuation"
-PREGNANCY = "pregnancy"
 PREGNANCY_NOTIFICATION_ACTION = "pregancy_notification_action"
 PROTOCOL_DEVIATION_VIOLATION_ACTION = "submit-protocol-deviation-violation"
 SAE = "sae"
 UNBLINDING_REQUEST_ACTION = "unblinding-request"
 UNBLINDING_REVIEW_ACTION = "unblinding-review"
 VIOLATION = "protocol_violation"
-WITHDRAWAL = "withdrawal"
-WITHDRAWAL_STUDY_MEDICATION_ACTION = "withdrawal_study_medication_action"
+OFFSTUDY_MEDICATION_ACTION = "withdrawal_study_medication_action"
