@@ -10,16 +10,15 @@ from meta_prn.constants import (
 )
 
 
-class OffSchedule(
-    ActionModelMixin, TrackingModelMixin, OffScheduleModelMixin, BaseUuidModel
-):
+class OffSchedule(ActionModelMixin, TrackingModelMixin, OffScheduleModelMixin, BaseUuidModel):
 
     action_name = OFFSCHEDULE_ACTION
 
     tracking_identifier_prefix = "OX"
 
     class Meta(OffScheduleModelMixin.Meta):
-        pass
+        verbose_name = "Off-schedule"
+        verbose_name_plural = "Off-schedule"
 
 
 class OffSchedulePregnancy(
@@ -30,7 +29,8 @@ class OffSchedulePregnancy(
     tracking_identifier_prefix = "OP"
 
     class Meta(OffScheduleModelMixin.Meta):
-        pass
+        verbose_name = "Off-schedule: Pregnancy"
+        verbose_name_plural = "Off-schedule: Pregnancy"
 
 
 class OffSchedulePostnatal(
@@ -41,4 +41,5 @@ class OffSchedulePostnatal(
     tracking_identifier_prefix = "ON"
 
     class Meta(OffScheduleModelMixin.Meta):
-        pass
+        verbose_name = "Off-schedule: post-natal"
+        verbose_name_plural = "Off-schedule: post-natal"
